@@ -132,7 +132,7 @@ impl DoviRpu {
 
             // rpu_alignment_zero_bit
             while !reader.is_aligned() {
-                dovi_rpu.remaining.push(reader.get());
+                dovi_rpu.remaining.push(reader.get()?);
             }
 
             // EOF case
@@ -141,7 +141,7 @@ impl DoviRpu {
             // CRC32 is at the end, apparently sometimes there is more unknown data
             if reader.available() != final_len {
                 while reader.available() != final_len {
-                    dovi_rpu.remaining.push(reader.get());
+                    dovi_rpu.remaining.push(reader.get()?);
                 }
             }
 
@@ -263,18 +263,34 @@ impl DoviRpu {
             };
         } else if self.dovi_profile == 5 && mode == 3 {
             self.p5_to_p81()?;
+        } else if self.dovi_profile == 8 && mode == 1 {
+            self.convert_to_mel()?;
         } else if mode != 0 {
             bail!("Invalid profile for mode {} conversion!", mode);
         }
 
+        // Update profile value
+        self.dovi_profile = self.header.get_dovi_profile();
+
         Ok(())
     }
 
     fn convert_to_mel(&mut self) -> Result<()> {
+        let header = &mut self.header;
+
+        header.el_spatial_resampling_filter_flag = true;
+        header.disable_residual_flag = false;
+
+        header.nlq_method_idc = Some(0);
+        header.nlq_num_pivots_minus2 = Some(0);
+        header.num_x_partitions_minus1 = 2046;
+
         if let Some(ref mut rpu_data_nlq) = self.rpu_data_nlq {
             rpu_data_nlq.convert_to_mel();
+        } else if self.dovi_profile == 8 {
+            self.rpu_data_nlq = Some(RpuDataNlq::mel_default());
         } else {
-            bail!("Not profile 7, cannot convert to MEL!");
+            bail!("Not profile 7 or 8, cannot convert to MEL!");
         }
 
         Ok(())
@@ -308,11 +324,15 @@ impl DoviRpu {
             self.header.bl_video_full_range_flag = false;
 
             self.header.num_pivots_minus_2 = [0, 0, 0];
-            self.header.pred_pivot_value.iter_mut().for_each(|v2| {
-                v2.truncate(2);
-                v2[0] = 0;
-                v2[1] = 1023;
-            });
+            self.header
+                .pred_pivot_value
+                .iter_mut()
+                .filter(|v| !v.is_empty())
+                .for_each(|v| {
+                    v.truncate(2);
+                    v[0] = 0;
+                    v[1] = 1023;
+                });
 
             if let Some(ref mut rpu_data_mapping) = self.rpu_data_mapping {
                 rpu_data_mapping.p5_to_p81();
