@@ -57,13 +57,17 @@ impl RpuDataMapping {
         for cmp in 0..NUM_COMPONENTS {
             let pivot_idx_count = (header.num_pivots_minus_2[cmp] + 1) as usize;
 
-            data.initialize_lists(cmp, pivot_idx_count);
+            data.mapping_idc[cmp].resize_with(pivot_idx_count, Default::default);
+            data.num_mapping_param_predictors[cmp].resize_with(pivot_idx_count, Default::default);
+            data.mapping_param_pred_flag[cmp].resize_with(pivot_idx_count, Default::default);
+            data.diff_pred_part_idx_mapping_minus1[cmp]
+                .resize_with(pivot_idx_count, Default::default);
 
             for pivot_idx in 0..pivot_idx_count {
-                data.mapping_idc[cmp][pivot_idx] = reader.get_ue();
+                data.mapping_idc[cmp][pivot_idx] = reader.get_ue()?;
 
                 if data.num_mapping_param_predictors[cmp][pivot_idx] > 0 {
-                    data.mapping_param_pred_flag[cmp][pivot_idx] = reader.get();
+                    data.mapping_param_pred_flag[cmp][pivot_idx] = reader.get()?;
                 } else {
                     data.mapping_param_pred_flag[cmp][pivot_idx] = false;
                 }
@@ -74,18 +78,33 @@ impl RpuDataMapping {
 
                     // MAPPING_POLYNOMIAL
                     if data.mapping_idc[cmp][pivot_idx] == 0 {
-                        data.poly_order_minus1[cmp][pivot_idx] = reader.get_ue();
+                        if data.poly_order_minus1[cmp].is_empty() {
+                            data.poly_order_minus1[cmp]
+                                .resize_with(pivot_idx_count, Default::default);
+                            data.linear_interp_flag[cmp]
+                                .resize_with(pivot_idx_count, Default::default);
+                        }
+
+                        data.poly_order_minus1[cmp][pivot_idx] = reader.get_ue()?;
 
                         if data.poly_order_minus1[cmp][pivot_idx] == 0 {
-                            data.linear_interp_flag[cmp][pivot_idx] = reader.get();
+                            data.linear_interp_flag[cmp][pivot_idx] = reader.get()?;
                         }
 
                         // Linear interpolation
                         if data.poly_order_minus1[cmp][pivot_idx] == 0
                             && data.linear_interp_flag[cmp][pivot_idx]
                         {
+                            if data.pred_linear_interp_value[cmp].is_empty() {
+                                data.pred_linear_interp_value_int[cmp]
+                                    .resize_with(pivot_idx_count, Default::default);
+                                data.pred_linear_interp_value[cmp]
+                                    .resize_with(pivot_idx_count, Default::default);
+                            }
+
                             if header.coefficient_data_type == 0 {
-                                data.pred_linear_interp_value_int[cmp][pivot_idx] = reader.get_ue();
+                                data.pred_linear_interp_value_int[cmp][pivot_idx] =
+                                    reader.get_ue()?;
                             }
 
                             data.pred_linear_interp_value[cmp][pivot_idx] =
@@ -94,13 +113,19 @@ impl RpuDataMapping {
                             if pivot_idx as u64 == header.num_pivots_minus_2[cmp] {
                                 if header.coefficient_data_type == 0 {
                                     data.pred_linear_interp_value_int[cmp][pivot_idx + 1] =
-                                        reader.get_ue();
+                                        reader.get_ue()?;
                                 }
 
                                 data.pred_linear_interp_value[cmp][pivot_idx + 1] =
                                     reader.get_n(coefficient_log2_denom_length);
                             }
                         } else {
+                            if data.poly_coef_int[cmp].is_empty() {
+                                data.poly_coef_int[cmp]
+                                    .resize_with(pivot_idx_count, Default::default);
+                                data.poly_coef[cmp].resize_with(pivot_idx_count, Default::default);
+                            }
+
                             let poly_coef_count =
                                 data.poly_order_minus1[cmp][pivot_idx] as usize + 1;
 
@@ -109,7 +134,7 @@ impl RpuDataMapping {
 
                             for i in 0..=poly_coef_count {
                                 if header.coefficient_data_type == 0 {
-                                    data.poly_coef_int[cmp][pivot_idx][i] = reader.get_se();
+                                    data.poly_coef_int[cmp][pivot_idx][i] = reader.get_se()?;
                                 }
 
                                 data.poly_coef[cmp][pivot_idx][i] =
@@ -118,17 +143,27 @@ impl RpuDataMapping {
                         }
                     } else if data.mapping_idc[cmp][pivot_idx] == 1 {
                         // MAPPING_MMR
+                        if data.mmr_order_minus1[cmp].is_empty() {
+                            data.mmr_order_minus1[cmp]
+                                .resize_with(pivot_idx_count, Default::default);
+                            data.mmr_constant_int[cmp]
+                                .resize_with(pivot_idx_count, Default::default);
+                            data.mmr_constant[cmp].resize_with(pivot_idx_count, Default::default);
+                            data.mmr_coef_int[cmp].resize_with(pivot_idx_count, Default::default);
+                            data.mmr_coef[cmp].resize_with(pivot_idx_count, Default::default);
+                        }
+
                         data.mmr_order_minus1[cmp][pivot_idx] = reader.get_n(2);
 
                         ensure!(data.mmr_order_minus1[cmp][pivot_idx] <= 2);
 
-                        data.mmr_coef[cmp][pivot_idx] =
-                            vec![vec![0; 7]; data.mmr_order_minus1[cmp][pivot_idx] as usize + 2];
                         data.mmr_coef_int[cmp][pivot_idx] =
                             vec![vec![0; 7]; data.mmr_order_minus1[cmp][pivot_idx] as usize + 2];
+                        data.mmr_coef[cmp][pivot_idx] =
+                            vec![vec![0; 7]; data.mmr_order_minus1[cmp][pivot_idx] as usize + 2];
 
                         if header.coefficient_data_type == 0 {
-                            data.mmr_constant_int[cmp][pivot_idx] = reader.get_se();
+                            data.mmr_constant_int[cmp][pivot_idx] = reader.get_se()?;
                         }
 
                         data.mmr_constant[cmp][pivot_idx] =
@@ -137,7 +172,7 @@ impl RpuDataMapping {
                         for i in 1..=data.mmr_order_minus1[cmp][pivot_idx] as usize + 1 {
                             for j in 0..7_usize {
                                 if header.coefficient_data_type == 0 {
-                                    data.mmr_coef_int[cmp][pivot_idx][i][j] = reader.get_se();
+                                    data.mmr_coef_int[cmp][pivot_idx][i][j] = reader.get_se()?;
                                 }
 
                                 data.mmr_coef[cmp][pivot_idx][i][j] =
@@ -146,7 +181,7 @@ impl RpuDataMapping {
                         }
                     }
                 } else if data.num_mapping_param_predictors[cmp][pivot_idx] > 1 {
-                    data.diff_pred_part_idx_mapping_minus1[cmp][pivot_idx] = reader.get_ue();
+                    data.diff_pred_part_idx_mapping_minus1[cmp][pivot_idx] = reader.get_ue()?;
                 }
             }
         }
@@ -278,90 +313,133 @@ impl RpuDataMapping {
     }
 
     pub fn p5_to_p81(&mut self) {
-        self.mapping_idc.iter_mut().for_each(|v| {
-            v.truncate(1);
-            v[0] = 0;
-        });
-
-        self.mapping_param_pred_flag.iter_mut().for_each(|v| {
-            v.truncate(1);
-            v[0] = false;
-        });
-
-        self.num_mapping_param_predictors.iter_mut().for_each(|v| {
-            v.truncate(1);
-            v[0] = 0;
-        });
-
-        self.diff_pred_part_idx_mapping_minus1
+        self.mapping_idc
             .iter_mut()
+            .filter(|v| !v.is_empty())
             .for_each(|v| {
                 v.truncate(1);
                 v[0] = 0;
             });
 
-        self.poly_order_minus1.iter_mut().for_each(|v| {
-            v.truncate(1);
-            v[0] = 0;
-        });
-
-        self.linear_interp_flag.iter_mut().for_each(|v| {
-            v.truncate(1);
-            v[0] = false;
-        });
-
-        self.pred_linear_interp_value_int.iter_mut().for_each(|v| {
-            v.truncate(1);
-            v[0] = 0;
-        });
-
-        self.pred_linear_interp_value.iter_mut().for_each(|v| {
-            v.truncate(1);
-            v[0] = 0;
-        });
-
-        self.poly_coef_int.iter_mut().for_each(|v| {
-            v.truncate(1);
-            v.iter_mut().for_each(|v2| {
-                v2.truncate(2);
-                v2[0] = 0;
-                v2[1] = 1;
+        self.mapping_param_pred_flag
+            .iter_mut()
+            .filter(|v| !v.is_empty())
+            .for_each(|v| {
+                v.truncate(1);
+                v[0] = false;
             });
-        });
 
-        self.poly_coef.iter_mut().for_each(|v| {
-            v.truncate(1);
-            v.iter_mut().for_each(|v2| {
-                v2.truncate(2);
-                v2[0] = 0;
-                v2[1] = 0;
+        self.num_mapping_param_predictors
+            .iter_mut()
+            .filter(|v| !v.is_empty())
+            .for_each(|v| {
+                v.truncate(1);
+                v[0] = 0;
             });
-        });
 
-        self.mmr_order_minus1.iter_mut().for_each(|v| {
-            v.truncate(1);
-            v[0] = 0;
-        });
+        self.diff_pred_part_idx_mapping_minus1
+            .iter_mut()
+            .filter(|v| !v.is_empty())
+            .for_each(|v| {
+                v.truncate(1);
+                v[0] = 0;
+            });
 
-        self.mmr_constant_int.iter_mut().for_each(|v| {
-            v.truncate(1);
-            v[0] = 0;
-        });
+        self.poly_order_minus1
+            .iter_mut()
+            .filter(|v| !v.is_empty())
+            .for_each(|v| {
+                v.truncate(1);
+                v[0] = 0;
+            });
 
-        self.mmr_constant.iter_mut().for_each(|v| {
-            v.truncate(1);
-            v[0] = 0;
-        });
+        self.linear_interp_flag
+            .iter_mut()
+            .filter(|v| !v.is_empty())
+            .for_each(|v| {
+                v.truncate(1);
+                v[0] = false;
+            });
 
-        self.mmr_coef_int.iter_mut().for_each(|v| {
-            v.truncate(1);
-            v[0] = vec![];
-        });
+        self.pred_linear_interp_value_int
+            .iter_mut()
+            .filter(|v| !v.is_empty())
+            .for_each(|v| {
+                v.truncate(1);
+                v[0] = 0;
+            });
 
-        self.mmr_coef.iter_mut().for_each(|v| {
-            v.truncate(1);
-            v[0] = vec![];
-        });
+        self.pred_linear_interp_value
+            .iter_mut()
+            .filter(|v| !v.is_empty())
+            .for_each(|v| {
+                v.truncate(1);
+                v[0] = 0;
+            });
+
+        self.poly_coef_int
+            .iter_mut()
+            .filter(|v| !v.is_empty())
+            .for_each(|v| {
+                v.truncate(1);
+                v.iter_mut().filter(|v| !v.is_empty()).for_each(|v2| {
+                    v2.truncate(2);
+                    v2[0] = 0;
+                    v2[1] = 1;
+                });
+            });
+
+        self.poly_coef
+            .iter_mut()
+            .filter(|v| !v.is_empty())
+            .for_each(|v| {
+                v.truncate(1);
+                v.iter_mut().filter(|v| !v.is_empty()).for_each(|v2| {
+                    v2.truncate(2);
+                    v2[0] = 0;
+                    v2[1] = 0;
+                });
+            });
+
+        self.mmr_order_minus1
+            .iter_mut()
+            .filter(|v| !v.is_empty())
+            .for_each(|v| {
+                v.truncate(1);
+                v[0] = 0;
+            });
+
+        self.mmr_constant_int
+            .iter_mut()
+            .filter(|v| !v.is_empty())
+            .for_each(|v| {
+                v.truncate(1);
+                v[0] = 0;
+            });
+
+        self.mmr_constant
+            .iter_mut()
+            .filter(|v| !v.is_empty())
+            .for_each(|v| {
+                v.truncate(1);
+                v[0] = 0;
+            });
+
+        self.mmr_coef_int
+            .iter_mut()
+            .filter(|v| !v.is_empty())
+            .for_each(|v| {
+                v.truncate(1);
+                v[0] = vec![];
+            });
+
+        self.mmr_coef
+            .iter_mut()
+            .filter(|v| !v.is_empty())
+            .for_each(|v| {
+                v.truncate(1);
+                v[0] = vec![];
+            });
     }
 
     pub fn p8_default() -> RpuDataMapping {
@@ -375,7 +453,7 @@ impl RpuDataMapping {
             pred_linear_interp_value_int: [vec![0], vec![0], vec![0]],
             pred_linear_interp_value: [vec![0], vec![0], vec![0]],
             poly_coef_int: [vec![vec![0, 1]], vec![vec![0, 1]], vec![vec![0, 1]]],
-            poly_coef: [vec![vec![0, 1]], vec![vec![0, 1]], vec![vec![0, 1]]],
+            poly_coef: [vec![vec![0, 0]], vec![vec![0, 0]], vec![vec![0, 0]]],
             mmr_order_minus1: [vec![0], vec![0], vec![0]],
             mmr_constant_int: [vec![0], vec![0], vec![0]],
             mmr_constant: [vec![0], vec![0], vec![0]],
@@ -383,26 +461,4 @@ impl RpuDataMapping {
             mmr_coef: [vec![vec![]], vec![vec![]], vec![vec![]]],
         }
     }
-
-    fn initialize_lists(&mut self, cmp: usize, count: usize) {
-        self.mapping_idc[cmp].resize_with(count, Default::default);
-        self.num_mapping_param_predictors[cmp].resize_with(count, Default::default);
-        self.mapping_param_pred_flag[cmp].resize_with(count, Default::default);
-        self.diff_pred_part_idx_mapping_minus1[cmp].resize_with(count, Default::default);
-
-        self.poly_order_minus1[cmp].resize_with(count, Default::default);
-        self.linear_interp_flag[cmp].resize_with(count, Default::default);
-
-        self.poly_coef_int[cmp].resize_with(count, Default::default);
-        self.poly_coef[cmp].resize_with(count, Default::default);
-
-        self.pred_linear_interp_value_int[cmp].resize_with(count, Default::default);
-        self.pred_linear_interp_value[cmp].resize_with(count, Default::default);
-        self.mmr_order_minus1[cmp].resize_with(count, Default::default);
-        self.mmr_constant_int[cmp].resize_with(count, Default::default);
-        self.mmr_constant[cmp].resize_with(count, Default::default);
-
-        self.mmr_coef_int[cmp].resize_with(count, Default::default);
-        self.mmr_coef[cmp].resize_with(count, Default::default);
-    }
 }
